@@ -1,7 +1,7 @@
 package DateTime::Calendar::TauStation;
-
+$DateTime::Calendar::TauStation::VERSION = '1.182260';
 use strict;
-use vars qw ( $VERSION $SECS_2_UNITS @EXPORT_OK );
+use vars qw ( $SECS_2_UNITS @EXPORT_OK );
 
 use Carp;
 use Exporter 'import';
@@ -10,9 +10,6 @@ use parent 'DateTime';
 
 require DateTime::Duration;
 
-$VERSION = '0.1.2';
-$VERSION = eval $VERSION;
-
 $SECS_2_UNITS = 0.864;
 
 @EXPORT_OK = qw( gct2seconds );
